==> simmate-0.10.0.tar.gz: simmate-0.10.0/README.md <==
<!-- This displays the Simmate Logo -->
<p align="center" href=https://simmate.org>
   <img src="https://github.com/jacksund/simmate/blob/main/src/simmate/website/static_files/images/simmate-logo-dark.svg?raw=true" width="700" style="max-width: 700px;">
</p>

<!-- This displays the dynamic badges -->
<p align="center">
<!-- Conda-forge OS support -->
<a href="https://anaconda.org/conda-forge/simmate">
    <img src="https://img.shields.io/badge/-Windows | Mac | Linux-00666b">
</a>
<!-- Pricing statement for begineers that are new to github -->
<a href="https://anaconda.org/conda-forge/simmate">
    <img src="https://img.shields.io/badge/-Free & Open Source-00666b">
</a>
<!-- link to JOSS paper -->
<a href="https://doi.org/10.21105/joss.04364">
    <img src="https://img.shields.io/badge/-DOI:10.21105/joss.04364-00666b">
</a>

</br>
<!-- Link to API documentation -->
<a href="https://jacksund.github.io/simmate/home/">
    <img src="https://img.shields.io/badge/-Tutorials & Docs-/?logo=microsoft-academic&color=00666b&logoColor=white">
</a>
<!-- Link to Website -->
<a href="https://simmate.org/">
    <img src="https://img.shields.io/badge/-Website-/?logo=iCloud&color=00666b&logoColor=white">
</a>
<!-- link to change-log -->
<a href="https://github.com/jacksund/simmate/blob/main/CHANGELOG.md">
    <img src="https://img.shields.io/badge/-Changes & Updates-/?logo=git-extensions&color=00666b&logoColor=white">
</a>
</p>

## About

The Simulated Materials Ecosystem (Simmate) is a toolbox and framework for computational materials research. It lets you explore various crystal databases, predict new materials, and quickly calculate properties.


## Before exploring the code

This Github repo holds all of our source code. Before getting started here, you may way to check out... 

- our main website at [simmate.org](https://simmate.org/)
- our tutorials and documentation at [jacksund/simmate](https://jacksund.github.io/simmate/home/)

## Need help or have a suggestion?

Post your question or feedback [here in our discussion section](https://github.com/jacksund/simmate/discussions/categories/q-a). 

Even if it's a question like "_How do I download all structures with x, y, and z properties?_", let us help out and point you in the right direction!

==> simmate-0.11.1.tar.gz: simmate-0.11.1/README.md <==
<!-- This displays the Simmate Logo -->
<p align="center" href=https://simmate.org>
   <img src="https://github.com/jacksund/simmate/blob/main/src/simmate/website/static_files/images/simmate-logo-dark.svg?raw=true" width="700" style="max-width: 700px;">
</p>

<!-- This displays the dynamic badges -->
<p align="center">
<!-- Conda-forge OS support -->
<a href="https://anaconda.org/conda-forge/simmate">
    <img src="https://img.shields.io/badge/-Windows | Mac | Linux-00666b">
</a>
<!-- Pricing statement for begineers that are new to github -->
<a href="https://anaconda.org/conda-forge/simmate">
    <img src="https://img.shields.io/badge/-Free & Open Source-00666b">
</a>
<!-- link to JOSS paper -->
<a href="https://doi.org/10.21105/joss.04364">
    <img src="https://img.shields.io/badge/-DOI:10.21105/joss.04364-00666b">
</a>

</br>
<!-- Link to API documentation -->
<a href="https://jacksund.github.io/simmate/home/">
    <img src="https://img.shields.io/badge/-Tutorials & Docs-/?logo=microsoft-academic&color=00666b&logoColor=white">
</a>
<!-- Link to Website -->
<a href="https://simmate.org/">
    <img src="https://img.shields.io/badge/-Website-/?logo=iCloud&color=00666b&logoColor=white">
</a>
<!-- link to change-log -->
<a href="https://github.com/jacksund/simmate/blob/main/CHANGELOG.md">
    <img src="https://img.shields.io/badge/-Changes & Updates-/?logo=git-extensions&color=00666b&logoColor=white">
</a>
</p>

## About

The Simulated Materials Ecosystem (Simmate) is a toolbox and framework for computational materials research. It lets you explore various crystal databases, predict new materials, and quickly calculate properties.


## Before exploring the code

This Github repo holds all of our source code. Before getting started here, you may way to check out... 

- our main website at [simmate.org](https://simmate.org/)
- our tutorials and documentation at [jacksund.github.io/simmate](https://jacksund.github.io/simmate/home/)

## Need help or have a suggestion?

Post your question or feedback [here in our discussion section](https://github.com/jacksund/simmate/discussions/categories/q-a). 

Even if it's a question like "_How do I download all structures with x, y, and z properties?_", let us help out and point you in the right direction!
